* OBJECTIVE: Regressions and summary tables for DT paper.

clear

set mem 1000m
set more off

capture log close
log using DT_Regressions.log, replace


************
* Settings *
************

* Define Directories
local cddir   = "/Users/titanalon/Documents/RA/Doepke/Progresa Project/"
local datadir = "/Users/titanalon/Documents/RA/Doepke/Progresa Project/Processed Data Sets/" //Where should cleaned data be saved?

cd "`cddir'"

use "`datadir'Progresa_Regressions_Data.dta", clear // read in data (see Progresa_Regressions_Data.do for details)


********************
* Create Variables *
********************

* Fille in missing eligibility\treatment data with 1997 characteristic files when possible
replace elig  = elig97  if elig ==.
replace treat = treat97 if treat==.

* Transfers Data -- see transfer processing do file for more details 

gen progresa_pay  = transf_avg
replace progresa_pay  = 0 if treat==0 //replace missing progresa payments with zero for those not treated
replace progresa_pay  = 0 if elig ==0 & progresa_pay == . // replace missing progresa payments with zero for those ineligible

* Expenditures Variables
gen logexp  =log(expenditure2)
gen log2exp =log(expenditure2)^2

* Income Variables
qui replace income  =income+progresa_pay+fsup+msup+kidsup
qui replace fincome =fincome+progresa_pay+fsup
qui replace mincome =mincome+msup

gen logincome  =log(income)
gen logincome2 =log(income)^2

* Female Income Share
gen finsh = fincome/income

* Implied Savings
gen sav_share =(income-expenditure2)/income

* Survey Dummies
replace dum99n = 0 if dum99n==.
replace dum99m = 0 if dum99m==.

* Expenditure Categories\Shares
// food variable already defined in levels
gen alctab     = (alco+tobacco)                 //alcohol and tabacco expenditure
gen womclothes = (women_clothing)               // women clothing
gen chiclothes = (girls_clothing+boys_clothing) //children clothing 
gen menclothes = (men_clothing)                 // men's clothing
gen other      = (services+transport)           //services and transportation

gen lalctab     = log(alctab)      //alcohol and tabacco expenditure
gen lfood       = log(food)        // food
gen lwomclothes = log(womclothes)  // women clothing 
gen lchiclothes = log(chiclothes)  // children clothing 
gen lmenclothes = log(menclothes)  // men's clothing 
gen lother      = log(other)       //services and transportation

// Define Shares using sum of categorical expenditures to ensure summing to one
gen exp_den     = food+alctab+womclothes+chiclothes+menclothes+other // denominator
gen salctab     = alctab/exp_den 
gen sfood       = food/exp_den
gen swomclothes = womclothes/exp_den
gen schiclothes = chiclothes/exp_den
gen smenclothes = menclothes/exp_den
gen sother      = other/exp_den


**********************
*** Winsorize Data ***
**********************

* Drop observations with zero expenditure (log(exp) not defined)
keep if expenditure2>0 & expenditure2~=.

* Drop if all category spending not available
keep if exp_den>0 & exp_den~=.

* Trim observations that yield extreme values for savings share
drop if sav_share<-5 | sav_share>1


************************************
*** Tables of Summary Statistics ***
************************************


* Table 1: Households by treatment\control & eligibility (poverty indicator)


tempfile rawdata
save `rawdata'

qui collapse (max) elig97 treat97 elig treat, by(folio)

qui drop if elig==. | treat==.

qui gen Eligibility = "."
qui replace Eligibility = "Poor" if elig == 1
qui replace Eligibility = "Nonpoor" if elig==0

qui gen Group = "."
qui replace Group = "Control" if treat==0
qui replace Group = "Treatment" if treat==1

tab Group
tab Group Eligibility, row

use `rawdata', clear /*restore dataset*/


* Table 2: Summary Statistics of Regressors, (a) pooled, (b) by survey wave, (c) by treatment\control


* 2(a) Pooled
tabstat progresa_pay income logincome expenditure2 logexp sav_share finsh hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage food alctab womclothes chiclothes menclothes other lfood lalctab lwomclothes lchiclothes lmenclothes lother sfood salctab swomclothes schiclothes smenclothes sother exp_den, stat(N mean sd IQR) col(stat)

* 2(b) By Survey Wave
qui gen wave="."
qui replace wave = "98 Oct" if tdum==1
qui replace wave = "99 Mar" if tdum==2
qui replace wave = "99 Nov" if tdum==3

tabstat progresa_pay income logincome expenditure2 logexp sav_share finsh hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage food alctab womclothes chiclothes menclothes other lfood lalctab lwomclothes lchiclothes lmenclothes lother sfood salctab swomclothes schiclothes smenclothes sother exp_den, by(wave) stat(N mean sd IQR) col(stat) nototal long

* 2(c) By Treatment\Control Indicator
qui label define tlabs 0 "Control" 1 "Treatment"
qui label values treat tlabs

tabstat progresa_pay income logincome expenditure2 logexp sav_share finsh hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage food alctab womclothes chiclothes menclothes other lfood lalctab lwomclothes lchiclothes lmenclothes lother sfood salctab swomclothes schiclothes smenclothes sother exp_den, by(treat) stat(N mean sd IQR) col(stat) nototal long

* Table 3: Work status of women

* (a) defined by reported time spent last week on various activities
label define nfjlabs 0 "Works" 1 "Doesn't Work"
label value nfj nfjlabs


label var nfj "Fem Work Status"
label var treat "Treatment Status"

tab nfj treat //women working by treatment group


* (b) seperating main job from other sources of work
* note: faj is indicator for women who spent time at "paid job"

label var faj "Female Paid Job"
label define fajlabs 0 "No Paid Job" 1 "Paid Job"
label value faj fajlabs 
rename faj fem_job

tabstat fem_job, by(treat) // share of women with "paid job" -- differs from "women working" -- see data file for details

* Redefinitions to combine (a) and (b)
gen femwork = (nfj==0) // these women do some work, recall = 1 if no female job
gen fem_work_nomain = femwork-fem_job // = 2 if women work other than paid job

label var fem_work_nomain "Female Work, No Job"

tabstat fem_work_nomain fem_job, by(treat) //breakdown women working by those with "paid job" and those doing other work (paid and not) excluding housework

* (c) by female income
gen feminc_noprogresa = fincome-progresa_pay-fsup 
gen femincind = (feminc_noprogresa>0) //some female income without progresa

label define femincindlabs 0 "No Income" 1 "Some Income"
label value femincind femincindlabs

tab femincind treat

***************************
*** Regressions Results ***
***************************

*  Convert shares to Percentages (multiply by 100)
replace salctab     = 100*salctab
replace swomclothes = 100*swomclothes
replace schiclothes = 100*schiclothes
replace smenclothes = 100*smenclothes
replace sfood       = 100*sfood

* Set 1: Basic Controls, OLS - RHS includes inc, inc^2, and female income share
foreach var of varlist salctab swomclothes schiclothes smenclothes sfood sother logexp sav_share {
	reg `var' finsh logincome logincome2  ,  robust  cluster(folio)	
}
*

* Set 2: Basic Controls, IV  - RHS includes inc, inc^2, and female income share
foreach var of varlist salctab swomclothes schiclothes smenclothes sfood sother logexp sav_share {
	ivreg `var' (finsh = progresa_pay) logincome logincome2  ,  robust  cluster(folio)	
}
*

* Set 3: Full Controls, OLS - RHS includes inc, inc^2, and female income share
foreach var of varlist salctab swomclothes schiclothes smenclothes sfood sother logexp sav_share {
	reg `var' finsh logincome logincome2 hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage   ,  robust  cluster(folio)	
}
*

* Set 4: Full Controls, IV  - RHS includes inc, inc^2, and female income share
foreach var of varlist salctab swomclothes schiclothes smenclothes sfood sother logexp sav_share {
	ivreg `var' (finsh = progresa_pay) logincome logincome2 hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage   ,  robust  cluster(folio)	
}
*

